@@ -6,7 +6,8 @@ SYS_DEPLOYMENT_FILE_NAME_VALUE = "deployment"
 
 STATUS_UNAVAILABLE = 'unavailable'
 SUCCESS_STATUSES = ['completed', 'available', 'success']
-WARNING_STATUSES = ['queued', 'pending', 'processing', 'building', 'validating', 'deploying', 'running']
+WARNING_STATUSES = ['queued', 'pending', 'processing', 'building', 'validating', 'deploying', 'running',
+                    'confirmation', 'confirmation_pending']
 ERROR_STATUSES = ['failed', 'cancelled_pending', 'cancelled']
 DEFAULT_IGNORE_FILE = '.ubiops-ignore'
 
